.. index:: contributors

.. _contributors:

===============
Contributors
===============

Stanislav Markov, Dept. Chemistry, The University of Hong Kong

Bálint Aradi, BCCMS, University of Bremen, Germany
